export declare abstract class BaseStorageService {
    private _s3StorageConnect;
    private _storage;
    private _nconf;
    constructor();
    abstract getFilePath(access: 'public' | 'private', fileSubType: 'avatar', fileType: 'user/avatar' | 'user/avatar-model', extension: string, userIdObj: Record<string, any> | null): Promise<string>;
    abstract returnMimeType(fileURL: string): string;
    abstract returnExtension(mimeType: string): string;
    /**
     *
     * @param key example path : 'output.zip'
     * @param expires
     * @param objType
     * @param contentType getObject | putObject
     * @description To get signedURL for viewing and updating an object.
     * @returns Promise<string>
     */
    getSignedURL(key: string, expires: any, objType: "getObject" | "putObject" | undefined, contentType: string): Promise<string>;
    /**
     *
     * @param fileURL example: https://s3.terrahost.com/bucketName/public/users/user_id/avatar/model.zip?someQuery=someValue&someOtherQuery=someOtherValue
     * @returns example: https://s3.terrahost.com/bucketName/public/users/user_id/avatar/model.zip
     */
    getPlainFileURL(fileURL: string): string;
    /**
     *
     * @param fileURL example: https://s3.terrahost.com/bucketName/public/users/user_id/avatar/model.zip
     * @returns example: public/users/user_id/avatar/model.zip
     */
    getObjectKey(fileURL: string): string;
    /**
     *
     * @param key example: /public/users/user_id/avatar/model.zip
     * @returns Lock will be added for the particular object.
     */
    addObjectLock(key: string): Promise<unknown>;
    /**
     *
     * @param key example: /public/users/user_id/avatar/model.zip
     * @returns Lock will be removed for the particular object.
     */
    removeObjectLock(key: string): Promise<unknown>;
}
